package whilelang

object Main {
  def main(args : Array[String]) : Unit = {
    if(args.length != 1) {
      Error("Please provide an input file.")
    }

    import java.io.{FileInputStream,IOException}

    val parser = new Parser

    try {
      val in = new FileInputStream(args(0))
      val parsed = parser.parseInputStream(in)

      println("Original program:")
      println("*****************\n")
      TreePrinter(parsed)

      val minimal = Conversion.convert(parsed)
      println("Minimal language program:")
      println("*****************\n")
      TreePrinter(minimal)

      val unrolled = Unrolling.unroll(minimal, 3)
      println("Unrolled program:")
      println("*****************\n")
      TreePrinter(unrolled)

      val formula = VCGen.compoVCG(unrolled)
      println("Formula for unrolled program:")
      println("*****************\n")
      println(formula);

    } catch {
      case e: IOException => Error(e.getMessage)
    }
  }
}
